DanzigPort = {{17,15}}

string_1 = NSLOCTEXT("scenario_DanzigCorridor", "string_1", "We have secured Danzig Port, now our battleship Schlewsig-Holstein (due to a lack of the unit in the game is represented as the BB Scharnhorst) is free to help our efforts in Gdynia and Hel peninsula.")

captured_depots = {}

function OnCaptureDanzigPort(action)

	-- If this flag was not captured by player 0(Axis), do nothing
	if(action.new_owner == 1) then return end

	-- Don't generate reward if the same depot is captured for the second time
	if IsItemInTable(captured_depots, action.flag) then return end

	if IsItemInTable(DanzigPort, action.flag) then	
	
		player = 0
		zone = { {17,15},{18,15},{17,16},{18,16},{17,17},{18,17},{19,17} }
		units = { {"BBScharnhorst", "", 0, 0}  }

		SpawnWave(player, zone, units)
	
		TutorialMessage(string_1)	

	-- Remember that this depot has been captured
	table.insert(captured_depots, action.flag)
	
	end
end


function CreateAndAssignEnemyHero1(unit_id)
	local hero = NewHero()
	hero.portrait = "/Game/Gui/Common/Heroes/generic_standin.generic_standin"
	hero.name = NSLOCTEXT("scenario_Antequera", "Leszek_Jaworski", "Leszek Jaworski")
	hero.extra_traits = {UnitTrait.Butcher}
	local action = world:MakeNewHeroAction(1, hero)
	world:Exec(action)

	local assign_hero_action = world:MakeAssignHeroAction(world:GetUnit(unit_id), hero.id)
	world:Exec(assign_hero_action)
end

function EnemyHero1()
	CreateAndAssignEnemyHero1(28) -- specify id of the unit which will get this hero
end

function CreateAndAssignEnemyHero2(unit_id)
	local hero = NewHero()
	hero.portrait = "/Game/Gui/Common/Heroes/generic_standin.generic_standin"
	hero.name = NSLOCTEXT("scenario_Antequera", "Jaroslaw_Gorski", "Jaroslaw Gorski")
	hero.extra_traits = {UnitTrait.Survivor}
	local action = world:MakeNewHeroAction(1, hero)
	world:Exec(action)

	local assign_hero_action = world:MakeAssignHeroAction(world:GetUnit(unit_id), hero.id)
	world:Exec(assign_hero_action)
end

function EnemyHero2()
	CreateAndAssignEnemyHero2(23) -- specify id of the unit which will get this hero
end



function SpawnWave(player, zone, units)
	local owner = world:GetPlayer(player)
	local cur_hex = 1

	-- Iterate through all units and spawn each one
	for _,u in ipairs(units) do
		-- Find the next vacant hex in the zone
		while zone[cur_hex] do
			hex = world:GetHex(zone[cur_hex])
			if hex:GetUnit(0) == nil then break end -- found
			cur_hex = cur_hex + 1
		end

		-- If we have run out of hexes in the zone, stop
		if not zone[cur_hex] then return end

		-- Create the unit in the free hex we've found
		-- 1. Create and execute purchase action, use unit type, transport type and overstrength as parameters
		local create_action = world:MakePurchaseAction(owner, u[1], u[2], u[3])
		create_action.auxiliary = false -- spawn core units
		create_action.cost = 0 -- don't take money for units we generate
		create_action.faction = owner.factions[1]  --set to first faction of owning player for created units
		world:Exec(create_action)

		-- 2. Create and execute deploy action, place the unit in the hex we've picked.
		local unit = world:GetUnit(create_action.id)
		deploy_action = world:MakeDeployAction(unit, zone[cur_hex])
		world:Exec(deploy_action)

		-- 3. Now modify the unit to set its experience to the value we need.
		unit.experience = u[4]
		
		-- 4. Now modify the unit to set its aggressiveness to the value we need.
		player_aggressiveness = { 0, 85, 70, 70 }
		unit.aggressiveness = player_aggressiveness[player+1]
	end
end


function OnObjective1(action)
	local comm = 0

	comm = 1
	campaign.comm_points = campaign.comm_points + comm

	local str2 = string.format(tostring(earned_cp_formatobj1), comm, campaign.comm_points)
	MessageBox(str2)
end

function OnObjective2(action)
    local comm = 0
    
    comm = 1
    campaign.comm_points = campaign.comm_points + comm
            
    local str2 = string.format(tostring(earned_cp_formatobj2), comm, campaign.comm_points)
    MessageBox(str2)
end

function Objective1Condition(action)
    return action.side == 0 and action.objective == 1 and action.status == ObjectiveStatus.Success
end

function Objective2Condition(action)
    return action.side == 0 and action.objective == 2 and action.status == ObjectiveStatus.Success
end   
    
earned_cp_formatobj1 = NSLOCTEXT("scenario_DanzigCorridor", "earned_cp_formatobj1", "Secondary objective to capture Hel Peninsula completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")
earned_cp_formatobj2 = NSLOCTEXT("scenario_DanzigCorridor", "earned_cp_formatobj2", "Secondary objective to Capture the Bridges over the Vistula completed.\nEarned Commendation Points: %d.\nTotal Commendation Points: %d.")
	

difficult_choice = NSLOCTEXT("scenario_DanzigCorridor", "difficult_choice", "General! I've heard that our forces have captured several Polish artillery pieces from Polish cities, Im sure if you can use some of your influence we can get them as a part of our core force.\n\nYou have %d Commendation Points.\n\nWould you like to exchange 2 Commendation Points for the Polish artillery?")

choice_made =
{
	NSLOCTEXT("scenario_DanzigCorridor", "choice_made1", "You decide to use some of your influence and accept the offer.  You now have %d Commendation Points."),
	NSLOCTEXT("scenario_DanzigCorridor", "choice_made2", "You choose to reject the offer.  You still have %d Commendation Points"),
}

function AlwaysTrue()
    return true
end
    
function OnStartGame()
	if (campaign.comm_points < 2) then return end
	local message = string.format(tostring(difficult_choice), campaign.comm_points)
	local choose_action = world:MakeChooseAction(0, message, "ProcessChoice")
	
	local option1 = 
	{
		title = NSLOCTEXT("scenario_DanzigCorridor", "option1", "Authorize the exchange"),
		tooltip = NSLOCTEXT("scenario_DanzigCorridor", "option1_tooltip", "")
	}
	local option2 =
	{
		title = NSLOCTEXT("scenario_DanzigCorridor", "option2", "Decline the exchange"),
		tooltip = NSLOCTEXT("scenario_DanzigCorridor", "option2_tooltip", "")
	}
	choose_action.options = {option1, option2}
	
	world:Exec(choose_action)
end

function ProcessChoice( player, choice )
	if (choice == 1) then
		-- The player chose option 1, which is "yes"
		campaign.comm_points = campaign.comm_points - 2
		AddEquipment(0, "155mmwz17", 20, Captured)
	end

	local str = string.format(tostring(choice_made[choice]), campaign.comm_points)
	MessageBox(str)
end

function FindItemInTable(table, item)
	for index,i in ipairs(table) do
		if i == item then
			return index 
		end
	end

	return -1
end

function IsItemInTable(table, item)
	return FindItemInTable(table, item) ~= -1
end

-- Possible categories: Prototypes, Captured, LimitedAvailability
function AddEquipment(player_id, unit_type, quantity, category)
	local player = world:GetPlayer(player_id)
	local equipment = player.equipment
	local type = GetUnitType(unit_type)
	local eq = equipment[type]
	if (eq == nil) then
		eq = NewEquipment()
		eq.category = category
		equipment[type] = eq
	end
	eq.quantity = eq.quantity + quantity
	player.equipment = equipment
end

function EmptyCondition()
	return true
end
